Django
======
Example factories for `Django <https://www.djangoproject.com/>`_ models.

Installation
------------
.. code-block:: sh

    pip install -r requirements.in

Testing
-------
.. code-block:: sh

    pytest

or

.. code-block:: sh

    python manage.py test
